# remirepo spec file for php-pecl-libsodium
#
# Copyright (c) 2014-2018 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%global sub_prefix %{scl_prefix}
%scl_package       php-pecl-libsodium
%endif

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global proj_name  libsodium
%global pecl_name  sodium
%global with_tests 0%{!?_without_tests:1}
%if "%{php_version}" < "5.6"
%global ini_name   %{pecl_name}.ini
%else
%global ini_name   40-%{pecl_name}.ini
%endif
%global buildver   %(pkg-config --silence-errors --modversion libsodium 2>/dev/null || echo 65536)

Summary:        Wrapper for the Sodium cryptographic library
Name:           %{?sub_prefix}php-pecl-%{proj_name}2
Version:        2.0.15
Release:        1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:        BSD
URL:            http://pecl.php.net/package/%{proj_name}
Source0:        http://pecl.php.net/get/%{proj_name}-%{version}.tgz

BuildRequires:  %{?dtsprefix}gcc
# Ensure libsodium-last is used (1.0.9 per upstream)
BuildRequires:  pkgconfig(libsodium) >= 1.0.15
BuildRequires:  %{?scl_prefix}php-devel > 7
BuildRequires:  %{?scl_prefix}php-devel < 7.2
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-json
BuildRequires:  pkgconfig

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
Requires:       libsodium%{?_isa} >= %{buildver}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{proj_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{proj_name})%{?_isa} = %{version}
%if "%{?scl_prefix}" != "%{?sub_prefix}"
Provides:       %{?scl_prefix}php-pecl-%{proj_name}2         = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl-%{proj_name}2%{?_isa} = %{version}-%{release}
%endif

%if "%{?vendor}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
%if "%{php_version}" > "7.0"
Obsoletes:     php70u-pecl-%{proj_name}2 <= %{version}
Obsoletes:     php70w-pecl-%{proj_name}2 <= %{version}
%endif
%if "%{php_version}" > "7.1"
Obsoletes:     php71u-pecl-%{proj_name}2 <= %{version}
Obsoletes:     php71w-pecl-%{proj_name}2 <= %{version}
%endif
%endif

# Filter shared private - always as libsodium.so is a bad name
%{?filter_provides_in: %filter_provides_in %{_libdir}/.*\.so$}
%{?filter_setup}


%description
A simple, low-level PHP extension for libsodium.

Documentation: https://paragonie.com/book/pecl-libsodium

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{scl_vendor})}.


%prep
%setup -q -c
mv %{proj_name}-%{version} NTS

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd NTS
sed -e '/PHP_SODIUM_VERSION/s/2.0.13/2.0.14/' -i php_libsodium.h

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_SODIUM_VERSION/{s/.* "//;s/".*$//;p}' php_libsodium.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{proj_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{proj_name}2/$i
done


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{proj_name} >/dev/null || :
fi
%endif


%check
cd NTS
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_tests}
: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=json.so -d extension=$PWD/modules/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php --show-diff
%endif

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_tests}
: Upstream test suite  for ZTS extension
TEST_PHP_EXECUTABLE=%{_bindir}/zts-php \
TEST_PHP_ARGS="-n -d extension=json.so -d extension=$PWD/modules/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{_bindir}/zts-php -n run-tests.php --show-diff
%endif
%endif


%files
%doc %{pecl_docdir}/%{proj_name}2
%{?_licensedir:%license NTS/LICENSE}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Mon Nov 19 2018 Remi Collet <remi@remirepo.net> - 2.0.15-1
- update to 2.0.15

* Wed Nov 14 2018 Remi Collet <remi@remirepo.net> - 2.0.14-1
- update to 2.0.14

* Sat Oct 13 2018 Remi Collet <remi@remirepo.net> - 2.0.13-1
- update to 2.0.13

* Wed Aug 29 2018 Remi Collet <remi@remirepo.net> - 2.0.12-1
- update to 2.0.12

* Wed May  2 2018 Remi Collet <remi@remirepo.net> - 2.0.11-1
- update to 2.0.11

* Sat Oct 28 2017 Remi Collet <remi@remirepo.net> - 2.0.10-1
- Update to 2.0.10
- open https://github.com/jedisct1/libsodium-php/pull/157 unneeded files

* Fri Oct 20 2017 Remi Collet <remi@remirepo.net> - 2.0.9-1
- Update to 2.0.9

* Sun Oct  1 2017 Remi Collet <remi@remirepo.net> - 2.0.8-1
- Update to 2.0.8
- rebuild for libsodium 1.0.15

* Thu Sep 28 2017 Remi Collet <remi@remirepo.net> - 2.0.7-2
- allow install of both v1 and v2 extensions

* Wed Sep 27 2017 Remi Collet <remi@remirepo.net> - 2.0.7-1
- Update to 2.0.7

* Tue Sep 26 2017 Remi Collet <remi@remirepo.net> - 2.0.6-1
- Update to 2.0.6

* Tue Sep 26 2017 Remi Collet <remi@remirepo.net> - 2.0.5-1
- Update to 2.0.5

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 2.0.4-1
- Update to 2.0.4
- open https://github.com/jedisct1/libsodium-php/pull/140 cleanup

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 2.0.3-1
- Update to 2.0.3
- open https://github.com/jedisct1/libsodium-php/issues/138 broken build
  and https://github.com/jedisct1/libsodium-php/pull/139

* Mon Jul 17 2017 Remi Collet <remi@fedoraproject.org> - 2.0.2-3
- rebuild with libsodium 1.0.13

* Mon Jul 17 2017 Remi Collet <remi@fedoraproject.org> - 2.0.2-1
- renamed to php-pecl-libsodium2 (new API)
- update to 2.0.2

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 1.0.6-3
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 1.0.6-2
- rebuild for PHP 7.1 new API version

* Thu May 05 2016 Remi Collet <remi@fedoraproject.org> - 1.0.6-1
- Update to 1.0.6

* Fri Apr 08 2016 Remi Collet <remi@fedoraproject.org> - 1.0.5-1
- Update to 1.0.5

* Tue Apr 05 2016 Remi Collet <remi@fedoraproject.org> - 1.0.4-1
- Update to 1.0.4 (no change since 1.0.3)

* Tue Apr  5 2016 Remi Collet <remi@fedoraproject.org> - 1.0.3-1
- Update to 1.0.3
- raise minimal PHP version to 5.4
- drop patch merged upstream

* Sun Mar  6 2016 Remi Collet <remi@fedoraproject.org> - 1.0.2-4
- adapt for F24

* Wed Dec  9 2015 Remi Collet <remi@fedoraproject.org> - 1.0.2-3
- rebuild against libsodium 1.0.7
- add upstream patch for test suite from
  https://github.com/jedisct1/libsodium-php/pull/70

* Wed Nov  4 2015 Remi Collet <remi@fedoraproject.org> - 1.0.2-2
- rebuild against libsodium 1.0.6

* Tue Oct 27 2015 Remi Collet <remi@fedoraproject.org> - 1.0.2-1
- Update to 1.0.2
- drop all patches, merged upstream

* Tue Oct 27 2015 Remi Collet <remi@fedoraproject.org> - 1.0.1-1
- Update to 1.0.1
- fix for old libsodium
  https://github.com/jedisct1/libsodium-php/pull/63
- don't zero interned string
  https://github.com/jedisct1/libsodium-php/pull/62
- add dependency on libsodium version used at build time

* Tue Oct 13 2015 Remi Collet <remi@fedoraproject.org> - 1.0.0-3
- rebuild for PHP 7.0.0RC5 new API version

* Fri Sep 18 2015 Remi Collet <remi@fedoraproject.org> - 1.0.0-2
- F23 rebuild with rh_layout

* Thu Sep 03 2015 Remi Collet <remi@fedoraproject.org> - 1.0.0-1
- Update to 1.0.0 (stable)

* Mon Jul 27 2015 Remi Collet <remi@fedoraproject.org> - 0.2.1-1
- Update to 0.2.1 (beta)

* Sun Jul 26 2015 Remi Collet <remi@fedoraproject.org> - 0.2.0-1
- Update to 0.2.0 (beta)

* Wed Jul 22 2015 Remi Collet <remi@fedoraproject.org> - 0.1.3-4
- rebuild against php 7.0.0beta2

* Wed Jul  8 2015 Remi Collet <remi@fedoraproject.org> - 0.1.3-3
- rebuild against php 7.0.0beta1

* Wed Jun 24 2015 Remi Collet <remi@fedoraproject.org> - 0.1.3-2
- allow build against rh-php56 (as more-php56)
- rebuild for "rh_layout" (php70)

* Wed Apr 15 2015 Remi Collet <remi@fedoraproject.org> - 0.1.3-1
- Update to 0.1.3 (beta)

* Thu Apr 02 2015 Remi Collet <remi@fedoraproject.org> - 0.1.2-1
- Update to 0.1.2 (beta)
- drop runtime dependency on pear, new scriptlets
- open https://github.com/jedisct1/libsodium-php/pull/22 - build
- open https://github.com/jedisct1/libsodium-php/pull/23 - php 7

* Wed Dec 24 2014 Remi Collet <remi@fedoraproject.org> - 0.1.1-1.1
- Fedora 21 SCL mass rebuild

* Sun Sep 28 2014 Remi Collet <rcollet@redhat.com> - 0.1.1-1
- initial package, version 0.1.1 (beta)
- open https://github.com/jedisct1/libsodium-php/pull/14

